import QtQuick
import QtQuick.Window
import QtQuick3D
import QtQuick3D.Effects

Window {
    visible: true
    x: 100
    y: 100
    width: 600
    height: 400
    title: qsTr("CustomMaterial and SceneEnvironment in a scene shared by multiple windows test")

    Node {
        id: scene3D
        DirectionalLight {
            id: directionalLight
        }

        PerspectiveCamera {
            id: camera
            z: 550
        }

        Model {
            id: sphere
            source: "#Sphere"
            x: 200
            materials: [
                DefaultMaterial {
                    diffuseColor: "blue"
                }
            ]
        }

        Model {
            id: cube
            source: "#Cube"
            x: -200
            materials: [
                CustomMaterial {
                    fragmentShader: "custom_material_default_shader.frag"
                }
            ]
        }
    }


    SceneEnvironment {
        id: sceneEnv
        // If effects line is commented out, child window content shows up, but custom Material
        // is using default shader.
        effects:  [ Blur {} ]
        backgroundMode: SceneEnvironment.Color
        clearColor: "lightgray"
    }

    View3D {
        anchors.fill: parent
        importScene: scene3D
        environment: sceneEnv
    }

    Window {
        id: childWindow
        x: 400
        y: 400
        width: 400
        height: 300
        visible: false

        View3D {
            anchors.fill: parent
            importScene: scene3D
            environment: sceneEnv
        }

        // Delay showing the window to allow imported scene to initialize in main window.
        // Comment out and set childWindow visible from start to test uninitialized case.
        // In that case, only the child window shows 3D content.
        Timer {
            interval: 1000
            triggeredOnStart: false
            running: true
            onTriggered: {
                childWindow.visible = true;
            }
        }
    }

}
